%% Script for manuscript: Modelling decadal salt marsh development: variability of the salt marsh extent under influence of waves and sediment availability? 
%% By: Pim Willemsen
%% p.willemsen@utwente.nl
%% Do not use without permission

%% Figure 3

close all; clear all; clc

%% Load data
folder = 'P:\11202744-008-vegetation-modelling\test_cases\saltmarsh_model\tests\tst_results\';

Hs000 = load([folder,'Hs000.mat']);
Hs005 = load([folder,'Hs005.mat']);
Hs010 = load([folder,'Hs010.mat']);
Hs010_SSC25 = load([folder,'Hs010_SSC25.mat']);
Hs010_SSC50 = load([folder,'Hs010_SSC50.mat']);
Hs015 = load([folder,'Hs015.mat']);

%% Figure Zoom of vegetation edge in last time step
F2 = figure;
%Parameters
T2 = 180;
EL = 1.25;
nsp1 = 4;
nsp2 = 5;
cmap = viridis;
%cmap = flipud(gray);
cmap = cmap;
cmap(1,:) = 1; 

%HS000
[X,Y] = meshgrid(0:5:995,0:5:2495);
XL = [0,1000];
YL = [350,850];
XT = [0,250,500,750,1000];
YT = [400,600,800];
YTlab = [2100,1900,1700];
xbox = [200,400,400,200,200];
ybox = [350,350,550,550,350];
zbox = [10000,10000,10000,10000,10000]
T_sel = [10*3.6,20*3.6,30*3.6,30*3.6,40*3.6,50*3.6];

SP2F{1} = subplot('Position',[0.08,0.75,0.2/2.5,0.2]);
P1 = surf(X,Y,Hs000.dat.rnveg_matrix{T2}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); 
axis equal; 
xlim(XL); ylim([0,2500]);  grid on;
% SP{5}.Position(4) = 0.11/5*4;

for j = [500:1000:2500]
    plot3(XL,[j,j],[10000,10000],'color',[0.15,0.15,0.15,0.15])
end

plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
    [10000,10000,10000,10000,10000],'-','color',[0.1906,0.4071,0.5561],'linewidth',1.5)
% plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
%     [10000,10000,10000,10000,10000],'-','color',[0.5,0.5,0.5],'linewidth',1.5)

plot3([500,500],[0,2500],[10000,10000],'color',[0.15,0.15,0.15,0.15]);
plot3(XL,[200,200],[10000,10000],'color','k');
plot3(XL,[2500,2500],[10000,10000],'color','k');
plot3([0,0],[0,2500],[10000,10000],'color','k')
plot3([1000,1000],[0,2500],[10000,10000],'color','k')
text(1300,1250,'H_s = 0.00m','rotation',90,'horizontalalignment','center','fontsize',9);
text(100,2300,2000,'a.')
set(gca,'xtick',XT,'xticklabels',[]);
set(gca,'ytick',[500:1000:2500],'yticklabels',fliplr([0:1000:2000]));
ylim([200,2500]);

SP2{1} = subplot('Position',[0.2,0.75,0.4,0.4*0.5])
P21 = surf(X,Y,Hs000.dat.rnveg_matrix{T2}'); hold on;
%SP2{1}.Position(4) = SP2{1}.Position(4)*EL;
colormap(cmap); P21.EdgeColor = 'none'; 
view(2); axis equal; xlim(XL); ylim(YL); grid on;

plot3(xbox,ybox,zbox,'r','linewidth',1.5);
% plot3(xbox,ybox,zbox,'color',[0.8,0.8,0.8],'linewidth',1.5);

for j = 1:3
    plot3(XL,[YT(j),YT(j)],[10000,10000],'color',[0.15,0.15,0.15,0.15])
    jx = j+1;
    plot3([XT(jx),XT(jx)],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
end
for j = 1:2
    plot3(XL,[YL(j),YL(j)],[10000,10000],'color','k')
    plot3([XL(j),XL(j)],YL,[10000,10000],'color','k')
end
plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
    [10000,10000,10000,10000,10000],'-','color',[0.1906,0.4071,0.5561],'linewidth',1.5)
% plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
%     [10000,10000,10000,10000,10000],'-','color',[0.5,0.5,0.5],'linewidth',1.5)
box on;
text(1060,600,'H_s = 0.00m','rotation',90,'horizontalalignment','center','fontsize',9);
text(25,805,2000,'b.')
set(gca,'xticklabel',[],'ytick',[YT],'yticklabel',[YTlab],'fontsize',9);

XL = [xbox(1),xbox(2)];
YL = [ybox(1),ybox(3)];
SP2Z{1} = subplot('Position',[0.63,0.75,0.2,0.2])
P21Z = surf(X,Y,Hs000.dat.rnveg_matrix{T2}'); hold on;
% SP2Z{1}.Position(4) = SP2{1}.Position(4);
colormap(cmap); P21Z.EdgeColor = 'none'; 
view(2); axis equal; xlim(XL); ylim(YL); grid on;
plot3(XL,[400,400],[10000,10000],'color',[0.15,0.15,0.15,0.15])
plot3(XL,[500,500],[10000,10000],'color',[0.15,0.15,0.15,0.15])
plot3([300,300],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])

plot3(xbox,ybox,zbox,'r','linewidth',1.5);
% plot3(xbox,ybox,zbox,'color',[0.8,0.8,0.8],'linewidth',1.5);
text(425,450,'H_s = 0.00m','rotation',90,'horizontalalignment','center','fontsize',9);
text(210,532,2000,'c.')
set(gca,'xticklabel',[],'ytick',[400,500],'yticklabel',[2100,2000]);

%HS005
XL = [0,1000];
YL = [250,750];
XT = [0,250,500,750,1000];
YT = [300,500,700];
YTlab = [2200,2000,1800];
ybox = [400,400,600,600,400];

SP2F{2} = subplot('Position',[0.08,0.53,0.2/2.5,0.2]);
P1 = surf(X,Y,Hs005.dat.rnveg_matrix{T2}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); 
axis equal; 
xlim(XL); ylim([0,2500]);  grid on;
% SP{5}.Position(4) = 0.11/5*4;

for j = [500:1000:2500]
    plot3(XL,[j,j],[10000,10000],'color',[0.15,0.15,0.15,0.15])
end

plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
    [10000,10000,10000,10000,10000],'-','color',[0.1906,0.4071,0.5561],'linewidth',1.5)
% plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
%     [10000,10000,10000,10000,10000],'-','color',[0.5,0.5,0.5],'linewidth',1.5)

plot3([500,500],[0,2500],[10000,10000],'color',[0.15,0.15,0.15,0.15]);
plot3(XL,[200,200],[10000,10000],'color','k');
plot3(XL,[2500,2500],[10000,10000],'color','k');
plot3([0,0],[0,2500],[10000,10000],'color','k')
plot3([1000,1000],[0,2500],[10000,10000],'color','k')
text(1300,1250,'H_s = 0.05m','rotation',90,'horizontalalignment','center','fontsize',9);
text(100,2300,2000,'d.')
set(gca,'xtick',XT,'xticklabels',[]);
set(gca,'ytick',[500:1000:2500],'yticklabels',fliplr([0:1000:2000]));
ylim([200,2500]);

SP2{2} = subplot('Position',[0.2,0.53,0.4,0.4*0.5])
P21 = surf(X,Y,Hs005.dat.rnveg_matrix{T2}'); hold on;
colormap(cmap); P21.EdgeColor = 'none'; 
view(2); axis equal; xlim(XL); ylim(YL); grid on;

plot3(xbox,ybox,zbox,'r','linewidth',1.5);
% plot3(xbox,ybox,zbox,'color',[0.8,0.8,0.8],'linewidth',1.5);

for j = 1:3
    plot3(XL,[YT(j),YT(j)],[10000,10000],'color',[0.15,0.15,0.15,0.15])
    jx = j+1;
    plot3([XT(jx),XT(jx)],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
end
for j = 1:2
    plot3(XL,[YL(j),YL(j)],[10000,10000],'color','k')
    plot3([XL(j),XL(j)],YL,[10000,10000],'color','k')
end
plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
    [10000,10000,10000,10000,10000],'-','color',[0.1906,0.4071,0.5561],'linewidth',1.5)
plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
    [10000,10000,10000,10000,10000],'-','color',[0.5,0.5,0.5],'linewidth',1.5)

box on;
text(1060,500,'H_s = 0.05m','rotation',90,'horizontalalignment','center','fontsize',9);
text(25,705,2000,'e.')
set(gca,'xticklabel',[],'ytick',[YT],'yticklabel',[YTlab],'fontsize',9);

XL = [xbox(1),xbox(2)];
YL = [ybox(1),ybox(3)];
SP2Z{2} = subplot('Position',[0.63,0.53,0.2,0.2])
P21Z = surf(X,Y,Hs005.dat.rnveg_matrix{T2}'); hold on;
colormap(cmap); P21Z.EdgeColor = 'none'; 
view(2); axis equal; xlim(XL); ylim(YL); grid on;
plot3(XL,[500,500],[10000,10000],'color',[0.15,0.15,0.15,0.15])
plot3([300,300],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])

plot3(xbox,ybox,zbox,'r','linewidth',1.5);
% plot3(xbox,ybox,zbox,'color',[0.8,0.8,0.8],'linewidth',1.5);

text(425,500,'H_s = 0.05m','rotation',90,'horizontalalignment','center','fontsize',9);
text(210,582,2000,'f.')
set(gca,'xticklabel',[],'yticklabel',[2100,2000,1900]);

%HS010
XL = [0,1000];
YL = [1100,1600];
XT = [0,250,500,750,1000];
YT = [1150,1350,1550];
YTlab = [2500,2500,2500]-YT;
ybox = [1150,1150,1350,1350,1150];

SP2F{3} = subplot('Position',[0.08,0.31,0.2/2.5,0.2]);
%P1 = surf(X,Y,Hs010.dat.rnveg_matrix{T_sel(5)}'); hold on;
P1 = surf(X,Y,Hs010.dat.rnveg_matrix{T2}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); 
axis equal; 
xlim(XL); ylim([0,2500]);  grid on;
% SP{5}.Position(4) = 0.11/5*4;

for j = [500:1000:2500]
    plot3(XL,[j,j],[10000,10000],'color',[0.15,0.15,0.15,0.15])
end

plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
    [10000,10000,10000,10000,10000],'-','color',[0.1906,0.4071,0.5561],'linewidth',1.5)
% plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
%     [10000,10000,10000,10000,10000],'-','color',[0.5,0.5,0.5],'linewidth',1.5)

plot3([500,500],[0,2500],[10000,10000],'color',[0.15,0.15,0.15,0.15]);
plot3(XL,[200,200],[10000,10000],'color','k');
plot3(XL,[2500,2500],[10000,10000],'color','k');
plot3([0,0],[0,2500],[10000,10000],'color','k')
plot3([1000,1000],[0,2500],[10000,10000],'color','k')
ylabel('                                cross-shore distance (m)');
text(1300,1250,'H_s = 0.10m','rotation',90,'horizontalalignment','center','fontsize',9);
text(100,2300,2000,'g.')
set(gca,'xtick',XT,'xticklabels',[]);
set(gca,'ytick',[500:1000:2500],'yticklabels',fliplr([0:1000:2000]));
ylim([200,2500]);

SP2{3} = subplot('Position',[0.2,0.31,0.4,0.4*0.5])
P21 = surf(X,Y,Hs010.dat.rnveg_matrix{T2}'); hold on;
colormap(cmap); P21.EdgeColor = 'none'; 
view(2); axis equal; xlim(XL); ylim(YL); grid on;

plot3(xbox,ybox,zbox,'r','linewidth',1.5);
% plot3(xbox,ybox,zbox,'color',[0.8,0.8,0.8],'linewidth',1.5);

for j = 1:3
    plot3(XL,[YT(j),YT(j)],[10000,10000],'color',[0.15,0.15,0.15,0.15])
    jx = j+1;
    plot3([XT(jx),XT(jx)],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
end
for j = 1:2
    plot3(XL,[YL(j),YL(j)],[10000,10000],'color','k')
    plot3([XL(j),XL(j)],YL,[10000,10000],'color','k')
end

plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
    [10000,10000,10000,10000,10000],'-','color',[0.1906,0.4071,0.5561],'linewidth',1.5)
% plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
%     [10000,10000,10000,10000,10000],'-','color',[0.5,0.5,0.5],'linewidth',1.5)

box on;
text(1060,1350,'H_s = 0.10m','rotation',90,'horizontalalignment','center','fontsize',9);
text(25,1555,2000,'h.')
set(gca,'xticklabel',[],'ytick',[YT],'yticklabel',[YTlab],'fontsize',9);

XL = [xbox(1),xbox(2)];
YL = [ybox(1),ybox(3)];
SP2Z{3} = subplot('Position',[0.63,0.31,0.2,0.2])
P21Z = surf(X,Y,Hs010.dat.rnveg_matrix{T2}'); hold on;
colormap(cmap); P21Z.EdgeColor = 'none'; 
view(2); axis equal; xlim(XL); ylim(YL); grid on;

plot3(xbox,ybox,zbox,'r','linewidth',1.5);
%plot3(xbox,ybox,zbox,'color',[0.8,0.8,0.8],'linewidth',1.5);

plot3(XL,[1200,1200],[10000,10000],'color',[0.15,0.15,0.15,0.15])
plot3(XL,[1300,1300],[10000,10000],'color',[0.15,0.15,0.15,0.15])
plot3([300,300],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
text(425,1250,'H_s = 0.10m','rotation',90,'horizontalalignment','center','fontsize',9);
text(210,1332,2000,'i.')
set(gca,'xticklabel',[],'ytick',[1200,1300],'yticklabel',[1300,1200]);

%HS015
XL = [0,1000];
YL = [2000,2500];
XT = [0,250,500,750,1000];
YT = [2050,2250,2450];
YTlab = [2500,2500,2500]-YT;
ybox = [2200,2200,2400,2400,2200];

SP2F{4} = subplot('Position',[0.08,0.09,0.2/2.5,0.2]);
P1 = surf(X,Y,Hs015.dat.rnveg_matrix{T2}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); 
axis equal; 
xlim(XL); ylim([0,2500]);  grid on;
% SP{5}.Position(4) = 0.11/5*4;

for j = [500:1000:2500]
    plot3(XL,[j,j],[10000,10000],'color',[0.15,0.15,0.15,0.15])
end

plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
    [10000,10000,10000,10000,10000],'-','color',[0.1906,0.4071,0.5561],'linewidth',1.5)
%plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
%    [10000,10000,10000,10000,10000],'-','color',[0.5,0.5,0.5],'linewidth',1.5)

plot3([500,500],[0,2500],[10000,10000],'color',[0.15,0.15,0.15,0.15]);
plot3(XL,[200,200],[10000,10000],'color','k');
plot3(XL,[2500,2500],[10000,10000],'color','k');
plot3([0,0],[0,2500],[10000,10000],'color','k')
plot3([1000,1000],[0,2500],[10000,10000],'color','k')
text(1300,1250,'H_s = 0.15m','rotation',90,'horizontalalignment','center','fontsize',9);
text(100,2300,2000,'j.')
set(gca,'xtick',[0,1000],'xticklabels',[0,1000]);
set(gca,'ytick',[500:1000:2500],'yticklabels',fliplr([0:1000:2000]));
ylim([200,2500]);

SP2{4} = subplot('Position',[0.2,0.09,0.4,0.4*0.5])
P21 = surf(X,Y,Hs015.dat.rnveg_matrix{T2}'); hold on;
colormap(cmap); P21.EdgeColor = 'none'; 
view(2); axis equal; xlim(XL); ylim(YL); grid on;

plot3(xbox,ybox,zbox,'r','linewidth',1.5);
%plot3(xbox,ybox,zbox,'color',[0.8,0.8,0.8],'linewidth',1.5);

for j = 1:3
    plot3(XL,[YT(j),YT(j)],[10000,10000],'color',[0.15,0.15,0.15,0.15])
    jx = j+1;
    plot3([XT(jx),XT(jx)],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
end
for j = 1:2
    plot3(XL,[YL(j),YL(j)],[10000,10000],'color','k')
    plot3([XL(j),XL(j)],YL,[10000,10000],'color','k')
end

plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
    [10000,10000,10000,10000,10000],'-','color',[0.1906,0.4071,0.5561],'linewidth',1.5)
%plot3([XL(1),XL(1),XL(2),XL(2),XL(1)],[YL(1),YL(2),YL(2),YL(1),YL(1)],...
%    [10000,10000,10000,10000,10000],'-','color',[0.5,0.5,0.5],'linewidth',1.5)

box on;
text(1060,2250,'H_s = 0.15m','rotation',90,'horizontalalignment','center','fontsize',9);
text(25,2455,2000,'k.')
set(gca,'ytick',[YT],'yticklabel',[YTlab],'fontsize',9);
xlabel('along-shore distance (m)');

XL = [xbox(1),xbox(2)];
YL = [ybox(1),ybox(3)];
SP2Z{4} = subplot('Position',[0.63,0.09,0.2,0.2])
P21Z = surf(X,Y,Hs015.dat.rnveg_matrix{T2}'); hold on;
colormap(cmap); P21Z.EdgeColor = 'none'; 
view(2); axis equal; xlim(XL); ylim(YL); grid on;
plot3(XL,[2300,2300],[10000,10000],'color',[0.15,0.15,0.15,0.15])
plot3(XL,[1300,1300],[10000,10000],'color',[0.15,0.15,0.15,0.15])
%plot3([300,300],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])

plot3(xbox,ybox,zbox,'r','linewidth',1.5);
% plot3(xbox,ybox,zbox,'color',[0.8,0.8,0.8],'linewidth',1.5);

text(425,2300,'H_s = 0.15m','rotation',90,'horizontalalignment','center','fontsize',9);
text(210,2382,2000,'l.')
set(gca,'yticklabel',[300,200,100]);

% colorbar
SP2{5} = subplot('Position',[0.86,0.065,0.05,0.915]);
P1 = surf(X,Y,Hs010.dat.rnveg_matrix{T_sel(4)}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); axis off; xlim([100000,100001]); ylim([100000,100001]); 
CB2 = colorbar('west'); 
ylabel(CB2,'vegetation density (stems m^-^2)','fontsize',9);
set(gca,'fontsize',9);
CB2.Position(1) = CB2.Position(1); 
CB2.Position(3) = CB2.Position(3)*2; 

set(findall(gcf,'-property','FontSize'),'FontSize',9)

print(F2,'TEnd_VegEdgeZoom_Landscape','-dpng','-r300')

%print(F2,'TEnd_VegEdgeZoom_Landscape_GS','-dpng','-r300')
