%% Script for manuscript: Modelling decadal salt marsh development: variability of the salt marsh extent under influence of waves and sediment availability? 
%% By: Pim Willemsen
%% p.willemsen@utwente.nl
%% Do not use without permission

%% Figure 5

close all; clear all; clc

%% Load data
folder = 'P:\11202744-008-vegetation-modelling\test_cases\saltmarsh_model\tests\tst_results\';

Hs000 = load([folder,'Hs000.mat']);
Hs005 = load([folder,'Hs005.mat']);
Hs010 = load([folder,'Hs010.mat']);
Hs010_SSC25 = load([folder,'Hs010_SSC25.mat']);
Hs010_SSC50 = load([folder,'Hs010_SSC50.mat']);
Hs015 = load([folder,'Hs015.mat']);

%% Plot data 

% Figure 1: subplots over time
% Parameters
[X,Y] = meshgrid(0:5:995,0:5:2495);
XL = [0,1000];
XT = [XL(1):500:XL(2)];

T_sel = [10*3.6,20*3.6,30*3.6,40*3.6,50*3.6];
Ys = {'year 10','year 20','year 30','year 40','year 50'};
cmap = viridis;
%cmap = flipud(gray);
cmap = cmap;
cmap(1,:) = 1; 

EL = 1.00;

ann_txt00 = {'a.','g.','m.','s.','y.'}
ann_txt05 = {'b.','h.','n.','t.','z.'}
ann_txt10_1 = {'c.','i.','o.','u.','aa.'}
ann_txt10_2 = {'d.','j.','p.','v.','bb.'}
ann_txt10_3 = {'e.','k.','q.','w.','cc.'}
ann_txt15 = {'f.','l.','r.','x.','dd.'}

% Figure
h = figure;

%Subs: Hs = 0.00
YL = [300,1100];
YT = [YL(1):400:YL(2)];
sps = [1,5,9,13,17];
for i = 1:4
    SP{i} = subplot('Position',[0.13,0.95-(0.12*i),0.11,0.11*4/5]);
    P1 = surf(X,Y,Hs000.dat.rnveg_matrix{T_sel(i)}'); hold on;
    colormap(cmap); P1.EdgeColor = 'none'; 
    view(2); 
    axis equal; 
    xlim(XL); ylim(YL); grid on;
    set(gca,'xtick',XT)
    set(gca,'ytick',YT)
    set(gca,'yticklabels',fliplr([1400:400:2200]));
    text(100,1000,2000,ann_txt00{i})
    for j = 2
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color',[0.15,0.15,0.15,0.15])
        plot3([XT(j),XT(j)],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
    end
    for j = [1:2:3]
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color','k')
        plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
    end
    if i<5
        set(gca,'xticklabels',[]);
    end
    if i==3
       ylabel('cross-shore distance (m)');
    end
    if i==1
       title({'H_s = 0.00m','SSC = 0.10mg/L'});
    end
end

SP{5} = subplot('Position',[0.13,0.16,0.11,0.11*2.5]);
P1 = surf(X,Y,Hs000.dat.rnveg_matrix{T_sel(5)}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); 
axis equal; 
xlim(XL); ylim([100,2500]);  grid on;
text(100,2400,2000,ann_txt00{5})

for j = [100:400:2500]
    plot3(XL,[j,j],[10000,10000],'color',[0.15,0.15,0.15,0.15])
end
for j = [1:2:3]
    plot3(XL,[YT(j),YT(j)],[10000,10000],'--','color',[0.5,0.5,0.5])
    plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
end
plot3([500,500],[0,2500],[10000,10000],'color',[0.15,0.15,0.15,0.15]);
plot3(XL,[0,0],[10000,10000],'color','k');
plot3(XL,[2500,2500],[10000,10000],'color','k');
plot3([0,0],[0,2500],[10000,10000],'color','k')
plot3([1000,1000],[0,2500],[10000,10000],'color','k')

set(gca,'xtick',XT)
set(gca,'ytick',[100:400:2500])
set(gca,'yticklabels',fliplr([0:400:2500]));

%Subs: Hs = 0.05
YL = [300,1100];
YT = [YL(1):400:YL(2)];
sps = [2,6,10,14,18];
for i = 1:4
    SP{i} = subplot('Position',[0.28,0.95-(0.12*i),0.11,0.11*4/5]);
    P1 = surf(X,Y,Hs005.dat.rnveg_matrix{T_sel(i)}'); hold on;
    colormap(cmap); P1.EdgeColor = 'none'; 
    view(2); axis equal; xlim(XL); ylim(YL); grid on;
    set(gca,'xtick',XT)
    set(gca,'ytick',YT)
    set(gca,'yticklabels',fliplr([1400:400:2200]));
    text(100,1000,2000,ann_txt05{i})
    for j = 2
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color',[0.15,0.15,0.15,0.15])
        plot3([XT(j),XT(j)],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
    end
    for j = [1:2:3]
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color','k')
        plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
    end
    if i<5
        set(gca,'xticklabels',[]);
    end
    if i==5
        xlabel('                                              along-shore distance (m)')
    end
    if i==1
        title({'H_s = 0.05m','SSC = 0.10mg/L'});
    end
end

SP{5} = subplot('Position',[0.28,0.16,0.11,0.11*2.5]);
P1 = surf(X,Y,Hs005.dat.rnveg_matrix{T_sel(5)}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); axis equal; xlim(XL); ylim([100,2500]); grid on;
SP{5}.Position(3:4) = SP{5}.Position(3:4)*EL;
text(100,2400,2000,ann_txt05{5})
for j = [100:400:2500]
    plot3(XL,[j,j],[10000,10000],'color',[0.15,0.15,0.15,0.15])
end
for j = [1:2:3]
    plot3(XL,[YT(j),YT(j)],[10000,10000],'--','color',[0.5,0.5,0.5])
    
    plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
end
plot3([500,500],[0,2500],[10000,10000],'color',[0.15,0.15,0.15,0.15]);
plot3(XL,[0,0],[10000,10000],'color','k');
plot3(XL,[2500,2500],[10000,10000],'color','k');
plot3([0,0],[0,2500],[10000,10000],'color','k')
plot3([1000,1000],[0,2500],[10000,10000],'color','k')
set(gca,'xtick',XT)
set(gca,'ytick',[100:400:2500])
set(gca,'yticklabels',fliplr([0:400:2500]));

%Subs: Hs = 0.10; SSC = 10
YL = [700,1500];
YT = [YL(1):400:YL(2)];
sps = [3,7,11,15,19];
for i = 1:4
    SP{i} = subplot('Position',[0.43,0.95-(0.12*i),0.11,0.11*4/5]);
    P1 = surf(X,Y,Hs010.dat.rnveg_matrix{T_sel(i)}'); hold on;
    colormap(cmap); P1.EdgeColor = 'none'; 
    view(2); axis equal; xlim(XL); ylim(YL); grid on;
    set(gca,'xtick',XT)
    set(gca,'ytick',YT)
    set(gca,'yticklabels',fliplr([1000:400:1800]));
    text(100,1400,2000,ann_txt10_1{i})
    for j = 2
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color',[0.15,0.15,0.15,0.15])
        plot3([XT(j),XT(j)],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
    end
    for j = [1:2:3]
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color','k')
        plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
    end
    if i<5
        set(gca,'xticklabels',[]);
    end
    if i==1
        title({'H_s = 0.10m','SSC = 0.10mg/L'});
    end
end

SP{5} = subplot('Position',[0.43,0.16,0.11,0.11*2.5]);
P1 = surf(X,Y,Hs010.dat.rnveg_matrix{T_sel(5)}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); axis equal; xlim(XL); ylim([100,2500]); grid on;
SP{5}.Position(3:4) = SP{5}.Position(3:4)*EL;
text(100,2400,2000,ann_txt10_1{5})
for j = [100:400:2500]
    plot3(XL,[j,j],[10000,10000],'color',[0.15,0.15,0.15,0.15])
end
for j = [1:2:3]
    plot3(XL,[YT(j),YT(j)],[10000,10000],'--','color',[0.5,0.5,0.5])
    
    plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
end
plot3([500,500],[0,2500],[10000,10000],'color',[0.15,0.15,0.15,0.15]);
plot3(XL,[0,0],[10000,10000],'color','k');
plot3(XL,[2500,2500],[10000,10000],'color','k');
plot3([0,0],[0,2500],[10000,10000],'color','k')
plot3([1000,1000],[0,2500],[10000,10000],'color','k')
xlabel('                                      along-shore distance (m)')
set(gca,'xtick',XT)
set(gca,'ytick',[100:400:2500])
set(gca,'yticklabels',fliplr([0:400:2500]));

%Subs: Hs = 0.10; SSC = 25
YL = [700,1500];
YT = [YL(1):400:YL(2)];
sps = [3,7,11,15,19];
for i = 1:4
    SP{i} = subplot('Position',[0.58,0.95-(0.12*i),0.11,0.11*4/5]);
    P1 = surf(X,Y,Hs010_SSC25.dat.rnveg_matrix{T_sel(i)}'); hold on;
    colormap(cmap); P1.EdgeColor = 'none'; 
    view(2); axis equal; xlim(XL); ylim(YL); grid on;
    set(gca,'xtick',XT)
    set(gca,'ytick',YT)
    set(gca,'yticklabels',fliplr([1000:400:1800]));
    text(100,1400,2000,ann_txt10_2{i})
    for j = 2
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color',[0.15,0.15,0.15,0.15])
        plot3([XT(j),XT(j)],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
    end
    for j = [1:2:3]
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color','k')
        plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
    end
    if i<5
        set(gca,'xticklabels',[]);
    end
    if i==1
        title({'H_s = 0.10m','SSC = 0.25mg/L'});
    end
end

SP{5} = subplot('Position',[0.58,0.16,0.11,0.11*2.5]);
P1 = surf(X,Y,Hs010_SSC25.dat.rnveg_matrix{T_sel(5)}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); axis equal; xlim(XL); ylim([100,2500]); grid on;
SP{5}.Position(3:4) = SP{5}.Position(3:4)*EL;
text(100,2400,2000,ann_txt10_2{5})
for j = [100:400:2500]
    plot3(XL,[j,j],[10000,10000],'color',[0.15,0.15,0.15,0.15])
end
for j = [1:2:3]
    plot3(XL,[YT(j),YT(j)],[10000,10000],'--','color',[0.5,0.5,0.5])
    
    plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
end
plot3([500,500],[0,2500],[10000,10000],'color',[0.15,0.15,0.15,0.15]);
plot3(XL,[0,0],[10000,10000],'color','k');
plot3(XL,[2500,2500],[10000,10000],'color','k');
plot3([0,0],[0,2500],[10000,10000],'color','k')
plot3([1000,1000],[0,2500],[10000,10000],'color','k')
set(gca,'xtick',XT)
set(gca,'ytick',[100:400:2500])
set(gca,'yticklabels',fliplr([0:400:2500]));

%Subs: Hs = 0.10; SSC = 50
YL = [700,1500];
YT = [YL(1):400:YL(2)];
sps = [3,7,11,15,19];
for i = 1:4
    SP{i} = subplot('Position',[0.73,0.95-(0.12*i),0.11,0.11*4/5]);
    P1 = surf(X,Y,Hs010_SSC50.dat.rnveg_matrix{T_sel(i)}'); hold on;
    colormap(cmap); P1.EdgeColor = 'none'; 
    view(2); axis equal; xlim(XL); ylim(YL); grid on;
    set(gca,'xtick',XT)
    set(gca,'ytick',YT)
    set(gca,'yticklabels',fliplr([1000:400:1800]));
    text(100,1400,2000,ann_txt10_3{i})
    for j = 2
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color',[0.15,0.15,0.15,0.15])
        plot3([XT(j),XT(j)],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
    end
    for j = [1:2:3]
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color','k')
        plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
    end
    if i<5
        set(gca,'xticklabels',[]);
    end
    if i==1
        title({'H_s = 0.10m','SSC = 0.50mg/L'});
    end
end

SP{5} = subplot('Position',[0.73,0.16,0.11,0.11*2.5]);
P1 = surf(X,Y,Hs010_SSC50.dat.rnveg_matrix{T_sel(5)}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); axis equal; xlim(XL); ylim([100,2500]); grid on;
SP{5}.Position(3:4) = SP{5}.Position(3:4)*EL;
text(100,2400,2000,ann_txt10_3{5})
for j = [100:400:2500]
    plot3(XL,[j,j],[10000,10000],'color',[0.15,0.15,0.15,0.15])
end
for j = [1:2:3]
    plot3(XL,[YT(j),YT(j)],[10000,10000],'--','color',[0.5,0.5,0.5])
    
    plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
end
plot3([500,500],[0,2500],[10000,10000],'color',[0.15,0.15,0.15,0.15]);
plot3(XL,[0,0],[10000,10000],'color','k');
plot3(XL,[2500,2500],[10000,10000],'color','k');
plot3([0,0],[0,2500],[10000,10000],'color','k')
plot3([1000,1000],[0,2500],[10000,10000],'color','k')
set(gca,'xtick',XT)
set(gca,'ytick',[100:400:2500])
set(gca,'yticklabels',fliplr([0:400:2500]));

%Subs: Hs = 0.15
YL = [1700,2500];
YT = [YL(1):400:YL(2)];
sps = [4,8,12,16,20];
for i = 1:4
    SP{i} = subplot('Position',[0.88,0.95-(0.12*i),0.11,0.11*4/5]);
    P1 = surf(X,Y,Hs015.dat.rnveg_matrix{T_sel(i)}'); hold on;
    colormap(cmap); P1.EdgeColor = 'none'; 
    view(2); axis equal; xlim(XL); ylim(YL); grid on;
    set(gca,'xtick',XT)
    set(gca,'ytick',YT)
    text(XL(end)+100,YT(2),10000,Ys{i},'color','k',...
        'horizontalalignment','center','rotation',90,'fontsize',8,'fontweight','bold');
    set(gca,'yticklabels',fliplr([0:400:800]));
    text(100,2400,2000,ann_txt15{i})
    for j = 2
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color',[0.15,0.15,0.15,0.15])
        plot3([XT(j),XT(j)],YL,[10000,10000],'color',[0.15,0.15,0.15,0.15])
    end
    for j = [1:2:3]
        plot3(XL,[YT(j),YT(j)],[10000,10000],'color','k')
        plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
    end
    if i<5
        set(gca,'xticklabels',[]);
    end
    if i==1
        title({'H_s = 0.15m','SSC = 0.10mg/L'});
    end
end


SP{5} = subplot('Position',[0.88,0.16,0.11,0.11*2.5]);
P1 = surf(X,Y,Hs015.dat.rnveg_matrix{T_sel(5)}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); axis equal; xlim(XL); ylim([100,2500]); grid on;
SP{5}.Position(3:4) = SP{5}.Position(3:4)*EL;
text(100,2400,2000,ann_txt15{5})
for j = [100:400:2500]
    plot3(XL,[j,j],[10000,10000],'color',[0.15,0.15,0.15,0.15])
end
for j = [1:2:3]
    plot3(XL,[YT(j),YT(j)],[10000,10000],'--','color',[0.5,0.5,0.5])
    
    plot3([XT(j),XT(j)],YL,[10000,10000],'color','k')
end
plot3([500,500],[0,2500],[10000,10000],'color',[0.15,0.15,0.15,0.15]);
plot3(XL,[0,0],[10000,10000],'color','k');
plot3(XL,[2500,2500],[10000,10000],'color','k');
plot3([0,0],[0,2500],[10000,10000],'color','k')
plot3([1000,1000],[0,2500],[10000,10000],'color','k')
 text(XL(end)+100,YT(2),10000,Ys{5},'color','k',...
        'horizontalalignment','center','rotation',90,'fontsize',8,'fontweight','bold');
set(gca,'xtick',XT)
set(gca,'ytick',[100:400:2500])
set(gca,'yticklabels',fliplr([0:400:2500]));

SPL = subplot('Position',[0.145,0.01,0.83,0.05]);
P1 = surf(X,Y,Hs010.dat.rnveg_matrix{T_sel(i)}'); hold on;
colormap(cmap); P1.EdgeColor = 'none';
view(2); axis off; xlim([100000,100001]); ylim([100000,100001]); 
CB = colorbar('northoutside'); 
set(CB,'YAxisLocation','bottom')
ylabel(CB,'vegetation density (stems m^-^2)','fontsize',9);
set(gca,'fontsize',9);
CB.Position(2) = CB.Position(2)+0.03; 
set(findall(gcf,'-property','FontSize'),'FontSize',9)

annotation('line',[0.25,0.25],[0.15,1],'Color','k','linestyle','--','linewidth',2)
annotation('line',[0.40,0.40],[0.15,1],'Color','k','linestyle','--','linewidth',2)
annotation('line',[0.85,0.85],[0.15,1],'Color','k','linestyle','--','linewidth',2)
set(h,'Units','Centimeters');
enl = 21/h.Position(3);
h.Position(3) = h.Position(3)*enl;
h.Position(4) = h.Position(4)*enl;
pos = get(h,'Position');
%set(h,'PaperPositionMode','Auto','PaperUnits','Centimeters','PaperSize',[pos(3), pos(4)])
print(h,'Summary_VegEdge_Landscape','-dpng','-r300')
%print(h,'Summary_VegEdge_Landscape_GS','-dpng','-r300')