%% Script for manuscript: Modelling decadal salt marsh development: variability of the salt marsh extent under influence of waves and sediment availability? 
%% By: Pim Willemsen
%% p.willemsen@utwente.nl
%% Do not use without permission

%% Figure 6

%% First run from dataset: 
% https://data.4tu.nl/articles/Data_presented_in_the_paper_Field-based_decadal_wave_attenuating_capacity_of_combined_tidal_flats_and_salt_marshes_/12693578 
% 2-Scripts\2-Figures\Figure5.m
ZUI_y40 = 11; %index 11 = 1976
PAU_y40 = 12; %index 12 = 1976

%% results field (vaklodingen)
val.ZUI.mean = -mean(ZUI.result_veglength(ZUI_y40:end,:)-ZUI.result_veglength(ZUI_y40,:))
val.ZUI.std = std(ZUI.result_veglength(ZUI_y40:end,:)-ZUI.result_veglength(ZUI_y40,:))
val.ZUI.min = -min(ZUI.result_veglength(ZUI_y40:end,:)-ZUI.result_veglength(ZUI_y40,:))
val.ZUI.max = -max(ZUI.result_veglength(ZUI_y40:end,:)-ZUI.result_veglength(ZUI_y40,:))
val.PAU.mean = -mean(PAU.result_veglength(PAU_y40:end,:)-PAU.result_veglength(PAU_y40,:))
val.PAU.std = std(PAU.result_veglength(PAU_y40:end,:)-PAU.result_veglength(PAU_y40,:))
val.PAU.min = -min(PAU.result_veglength(PAU_y40:end,:)-PAU.result_veglength(PAU_y40,:))
val.PAU.max = -max(PAU.result_veglength(PAU_y40:end,:)-PAU.result_veglength(PAU_y40,:))

val.ZUI.mean_tot = -mean2(ZUI.result_veglength(ZUI_y40:end,:)-ZUI.result_veglength(ZUI_y40,:))
val.ZUI.std_tot = std2(ZUI.result_veglength(ZUI_y40:end,:)-ZUI.result_veglength(ZUI_y40,:))
val.ZUI.min_tot = -min(min(ZUI.result_veglength(ZUI_y40:end,:)-ZUI.result_veglength(ZUI_y40,:)))
val.ZUI.max_tot = -max(max(ZUI.result_veglength(ZUI_y40:end,:)-ZUI.result_veglength(ZUI_y40,:)))
val.PAU.mean_tot = -mean2(PAU.result_veglength(PAU_y40:end,:)-PAU.result_veglength(PAU_y40,:))
val.PAU.std_tot = std2(PAU.result_veglength(PAU_y40:end,:)-PAU.result_veglength(PAU_y40,:))
val.PAU.min_tot = -min(min(PAU.result_veglength(PAU_y40:end,:)-PAU.result_veglength(PAU_y40,:)))
val.PAU.max_tot = -max(max(PAU.result_veglength(PAU_y40:end,:)-PAU.result_veglength(PAU_y40,:)))

%% results model [10years, 40years]
% Obtain statistics of dynamics of location of simulated salt marsh edge
% dat.veg_edge.mean_all2 is used from VegDens_stack.m (projectfolder Deltares)
val.MOD000.mean = -[-21,-48]; 							
val.MOD000.std = [8,11]; 								
val.MOD000.min = -[-170,-240]; 							
val.MOD000.max = -[10,5]; 								
val.MOD005.mean = -[-11,-43]; 	
val.MOD005.std = [16,21]; 		
val.MOD005.min = -[-130,-145]; 
val.MOD005.max = -[85,0]; 	
val.MOD010.mean = -[115,99]; 
val.MOD010.std = [120,172]; 
val.MOD010.min = -[-205,-460]; 	
val.MOD010.max = -[1230,930]; 
val.MOD015.mean = -[1,66]; 		
val.MOD015.std = [1,29]; 	
val.MOD015.min = -[-5,-50];
val.MOD015.max = -[5,90]; 	

val.MOD010_SSC25.mean = [64]; 
val.MOD010_SSC25.std = [218]; 
val.MOD010_SSC25.min = -[-500]; 
val.MOD010_SSC25.max = -[855];
val.MOD010_SSC50.mean = [51]; 
val.MOD010_SSC50.std = [147]; 
val.MOD010_SSC50.min = -[-525]; 
val.MOD010_SSC50.max = -[655];

%% Plot results
MS = 5;
XL = [-1,39.5];
YL = [-400,400];
figure;
plot(XL,[0,0],'--k');
hold on;
plot([.5,.5],[-500,500],'-k','linewidth',2);
plot([18.5,18.5],[-500,500],'-k','linewidth',2);
plot([30.5,30.5],[-500,500],'-k','linewidth',2);
fill([-1,-1,0.5,0.5],[-500,500,500,-500],[0.4,0.4,0.4],'FaceAlpha',0.5,'LineStyle','none');
fill([8.5,8.5,18.5,18.5],[-500,500,500,-500],[0.7,0.7,0.7],'FaceAlpha',0.2,'LineStyle','none');
fill([24.5,24.5,30.5,30.5],[-500,500,500,-500],[0.7,0.7,0.7],'FaceAlpha',0.2,'LineStyle','none');
fill([30.5,30.5,39.5,39.5],[-500,500,500,-500],[0.7,0.7,0.7],'FaceAlpha',0.2,'LineStyle','none');
cmap1 = [183/255,222/255,41/255];
for i = 1:9
    plot([i+8.5,i+8.5],[val.ZUI.mean(i)-val.ZUI.std(i),val.ZUI.mean(i)+val.ZUI.std(i)],'color',cmap1,'linewidth',4);
    plot([i+8.5],[val.ZUI.mean(i)],'ok','markersize',MS,'markeredgecolor',cmap1,'markerfacecolor','w');
    text(i+8.5,val.ZUI.mean(i)+val.ZUI.std(i)+25,num2str(i),'horizontalalignment','center')
end

cmap1 = [183/255,222/255,41/255];
for i = 1:7
    plot([i+.5,i+.5],[val.PAU.mean(i)-val.PAU.std(i),val.PAU.mean(i)+val.PAU.std(i)],'color',cmap1,'linewidth',4);
    plot([i+.5],[val.PAU.mean(i)],'ok','markersize',MS,'markeredgecolor',cmap1,'markerfacecolor','w');
    text(i+.5,val.PAU.mean(i)+val.PAU.std(i)+25,num2str(i),'horizontalalignment','center')
end

cmap3 = [41/255,121/255,142/255];
cmap4 = [72/255,24/255,106/255];
for i = 2
    if i==1
        cmap = cmap3;
    end
    if i==2
        cmap = cmap3;
    end
    plot([i+18.5-0.5,i+18.5-0.5],[val.MOD000.mean(i)-val.MOD000.std(i),val.MOD000.mean(i)+val.MOD000.std(i)],'color',cmap,'linewidth',4);
    plot([i+18.5-0.5],[val.MOD000.mean(i)],'ok','markersize',MS,'markeredgecolor',cmap,'markerfacecolor','w');
end
for i = 2
    if i==1
        cmap = cmap3;
    end
    if i==2
        cmap = cmap3;
    end
    plot([i+21.5-0.5,i+21.5-0.5],[val.MOD005.mean(i)-val.MOD005.std(i),val.MOD005.mean(i)+val.MOD005.std(i)],'color',cmap,'linewidth',4);
    plot([i+21.5-0.5],[val.MOD005.mean(i)],'ok','markersize',MS,'markeredgecolor',cmap,'markerfacecolor','w');
end
for i = 2
    if i==1
        cmap = cmap3;
    end
    if i==2
        cmap = cmap3;
    end
    plot([i+24.5-0.5,i+24.5-0.5],[val.MOD010.mean(i)-val.MOD010.std(i),val.MOD010.mean(i)+val.MOD010.std(i)],'color',cmap,'linewidth',4);
    plot([i+24.5-0.5],[val.MOD010.mean(i)],'ok','markersize',MS,'markeredgecolor',cmap,'markerfacecolor','w');
end

for i = 2
    if i==1
        cmap = cmap3;
    end
    if i==2
        cmap = cmap3;
    end
    plot([i+27.5-0.5,i+27.5-0.5],[val.MOD015.mean(i)-val.MOD015.std(i),val.MOD015.mean(i)+val.MOD015.std(i)],'color',cmap,'linewidth',4);
    plot([i+27.5-0.5],[val.MOD015.mean(i)],'ok','markersize',MS,'markeredgecolor',cmap,'markerfacecolor','w');
end

for i = 2
    if i==1
        cmap = cmap3;
    end
    if i==2
        cmap = cmap3;
    end
    plot([i+30.5-0.5,i+30.5-0.5],[val.MOD010.mean(i)-val.MOD010.std(i),val.MOD010.mean(i)+val.MOD010.std(i)],'color',cmap,'linewidth',4);
    plot([i+30.5-0.5],[val.MOD010.mean(i)],'ok','markersize',MS,'markeredgecolor',cmap,'markerfacecolor','w');
end

for i = 1
    cmap = cmap3;
    plot([i+33.5+0.5,i+33.5+0.5],[val.MOD010_SSC25.mean(i)-val.MOD010_SSC25.std(i),val.MOD010_SSC25.mean(i)+val.MOD010_SSC25.std(i)],'color',cmap,'linewidth',4);
    plot([i+33.5+0.5],[val.MOD010_SSC25.mean(i)],'ok','markersize',MS,'markeredgecolor',cmap,'markerfacecolor','w');
end
for i = 1
    cmap = cmap3;
    plot([i+36.5+0.5,i+36.5+0.5],[val.MOD010_SSC50.mean(i)-val.MOD010_SSC50.std(i),val.MOD010_SSC25.mean(i)+val.MOD010_SSC25.std(i)],'color',cmap,'linewidth',4);
    plot([i+36.5+0.5],[val.MOD010_SSC50.mean(i)],'ok','markersize',MS,'markeredgecolor',cmap,'markerfacecolor','w');
end

text(24.5,359,'model; H_s','horizontalalignment','center','fontweight','bold')
text(35,365,'model; SSC','horizontalalignment','center','fontweight','bold')
text(9,365,'field','horizontalalignment','center','fontweight','bold')
text(13.5,YL(1)+90,'Zuidgors','horizontalalignment','center','verticalalignment','bottom')
text(13.5,YL(1)+33,{'H_s ='},'horizontalalignment','center','verticalalignment','bottom')
text(13.5,YL(1)+7,{'0.14m'},'horizontalalignment','center','verticalalignment','bottom')
text(4.5,YL(1)+90,'Paulinapolder','horizontalalignment','center','verticalalignment','bottom')
text(4.5,YL(1)+33,{'H_s ='},'horizontalalignment','center','verticalalignment','bottom')
text(4.5,YL(1)+7,{'0.05m'},'horizontalalignment','center','verticalalignment','bottom')
text(20,YL(1)+33,{'H_s ='},'horizontalalignment','center','verticalalignment','bottom')
text(23,YL(1)+33,{'H_s ='},'horizontalalignment','center','verticalalignment','bottom')
text(26,YL(1)+33,{'H_s ='},'horizontalalignment','center','verticalalignment','bottom')
text(29,YL(1)+33,{'H_s ='},'horizontalalignment','center','verticalalignment','bottom')
text(20,YL(1)+7,{'0.00m'},'horizontalalignment','center','verticalalignment','bottom')
text(23,YL(1)+7,{'0.05m'},'horizontalalignment','center','verticalalignment','bottom')
text(26,YL(1)+7,{'0.10m'},'horizontalalignment','center','verticalalignment','bottom')
text(29,YL(1)+7,{'0.15m'},'horizontalalignment','center','verticalalignment','bottom')
text(32,YL(1)+45,{'SSC ='},'horizontalalignment','center','verticalalignment','bottom')
text(35,YL(1)+45,{'SSC ='},'horizontalalignment','center','verticalalignment','bottom')
text(38,YL(1)+45,{'SSC ='},'horizontalalignment','center','verticalalignment','bottom')
text(32,YL(1)+7,{'10mg/L'},'horizontalalignment','center','verticalalignment','bottom')
text(35,YL(1)+7,{'25mg/L'},'horizontalalignment','center','verticalalignment','bottom')
text(38,YL(1)+7,{'50mg/L'},'horizontalalignment','center','verticalalignment','bottom')
text(-0.5,-105,'retreating','horizontalalignment','right','rotation',90);

text(-0.5,105,'expanding','rotation',90);
plot([-0.33,-0.33],[10,80],'k','linewidth',2);
plot([-0.33],[80],'^k','markerfacecolor','k');
plot([-0.33,-0.33],[-10,-80],'k','linewidth',2);
plot([-0.33],[-80],'vk','markerfacecolor','k');
text(18.5,325,'  exposure \rightarrow + 				         		                 sediment \rightarrow +             ','horizontalalignment','left','fontweight','bold')
grid on; xlim(XL); ylim(YL); set(gca,'xtick',[],'xticklabels',[]);
ylabel('marsh edge variability (m)')
PL1 = plot([100,100],[val.MOD010.min(i),val.MOD010.max(i)],'color','k','linewidth',1);
PL2 = plot([100,100],[val.MOD010.mean(i)-val.MOD010.std(i),val.MOD010.mean(i)+val.MOD010.std(i)],'color','k','linewidth',4);
PL3 = plot([100],[val.MOD010.mean(i)],'ok','markersize',MS,'markeredgecolor','k','markerfacecolor','w');
PL4 = plot([100,100],[val.MOD010.mean(i)-val.MOD010.std(i),val.MOD010.mean(i)+val.MOD010.std(i)],'color',cmap1,'linewidth',4);
PL5 = plot([100,100],[val.MOD010.mean(i)-val.MOD010.std(i),val.MOD010.mean(i)+val.MOD010.std(i)],'color',cmap3,'linewidth',4);
PL6 = plot([100,100],[val.MOD010.mean(i)-val.MOD010.std(i),val.MOD010.mean(i)+val.MOD010.std(i)],'color',cmap4,'linewidth',4);
legend([PL4,PL5],{'field 40y','model 40y'},'location','northwest');