%% Script for manuscript: Modelling decadal salt marsh development: variability of the salt marsh extent under influence of waves and sediment availability? 
%% By: Pim Willemsen
%% p.willemsen@utwente.nl
%% Do not use without permission

%% Figure 7

close all; clear all; clc;

%% Load data and set parameters 
file000 = 'P:\11202744-008-vegetation-modelling\test_cases\saltmarsh_model\tests\tst_EQProfileWS2_Nested_Constant1_FricWav_0.038_NAVegPar_Hs000\fm\DFM_OUTPUT_FlowFM\FlowFM_map.nc';
file005 = 'P:\11202744-008-vegetation-modelling\test_cases\saltmarsh_model\tests\tst_EQProfileWS2_Nested_Constant1_FricWav_0.038_NAVegPar_Hs005_CInund_3000\fm\DFM_OUTPUT_FlowFM\FlowFM_map.nc';
file010 = 'P:\11202744-008-vegetation-modelling\test_cases\saltmarsh_model\tests\tst_EQProfileWS2_Nested_Constant1_FricWav_0.038_NAVegPar_Hs010\fm\DFM_OUTPUT_FlowFM_02\FlowFM_map.nc';
file015 = 'P:\11202744-008-vegetation-modelling\test_cases\saltmarsh_model\tests\tst_EQProfileWS2_Nested_Constant1_FricWav_0.038_NAVegPar_Hs015\fm\DFM_OUTPUT_FlowFM\FlowFM_map.nc';
M = 200;
N = 500;
cellsize = 5;
X_arr = [0:cellsize:cellsize*N-cellsize];

dat.x{1} = ncread(file000,'mesh2d_face_x');
dat.x{2} = ncread(file005,'mesh2d_face_x');
dat.x{3} = ncread(file010,'mesh2d_face_x'); 
dat.x{4} = ncread(file015,'mesh2d_face_x');
dat.y{1} = ncread(file000,'mesh2d_face_y');
dat.y{2} = ncread(file005,'mesh2d_face_y');
dat.y{3} = ncread(file010,'mesh2d_face_y');
dat.y{4} = ncread(file015,'mesh2d_face_y');
dat.bl_day{1} = ncread(file000,'mesh2d_mor_bl',[1,3457],[inf,inf],[1,24]);
dat.bl_day{2} = ncread(file005,'mesh2d_mor_bl',[1,3457],[inf,inf],[1,24]);
dat.bl_day{3} = ncread(file010,'mesh2d_mor_bl',[1,3457],[inf,inf],[1,24]);
dat.bl_day{4} = ncread(file015,'mesh2d_mor_bl',[1,3457],[inf,inf],[1,24]);

dat.rnveg_day{1} = ncread(file000,'mesh2d_rnveg',[1,3457],[inf,inf],[1,24]);
dat.rnveg_day{2} = ncread(file005,'mesh2d_rnveg',[1,3457],[inf,inf],[1,24]);
dat.rnveg_day{3} = ncread(file010,'mesh2d_rnveg',[1,3457],[inf,inf],[1,24]);
dat.rnveg_day{4} = ncread(file015,'mesh2d_rnveg',[1,3457],[inf,inf],[1,24]);

%% Sort data 
for i = 1:4
    [dat.y_Val_sort{i},dat.I_sort{i}] = sort(dat.y{i});
    for j = 1:size(dat.bl_day{i},2)
        dat.bl_sorted{i}{j}     = dat.bl_day{i}(dat.I_sort{i},j);
        dat.bl_matrix{i}{j}     = reshape(dat.bl_sorted{i}{j},[M,N]);  % reshape to matrix
        [~,dat.bl.ind_max{i}{j}]      = max(diff(dat.bl_matrix{i}{j}')); % find marsh edge
        dat.bl_longshoremean{i}(1:500,j) = mean(dat.bl_matrix{1,i}{j});
        dat.bl_longshorestd{i}(1:500,j)    = std(dat.bl_matrix{1,i}{j});
    end
    for k = 1:size(dat.rnveg_day{i},2)
        dat.rnveg_sorted{i}{k}     = dat.rnveg_day{i}(dat.I_sort{i},k);
        dat.rnveg_matrix{i}{k}     = reshape(dat.rnveg_sorted{i}{k},[M,N]);  % reshape to matrix
        dat.rnveg_matrix{i}{k}(:,1:40) = 0;
        dat.rnveg_matrix2{i}{k}=dat.rnveg_matrix{i}{k};
        for h = 1:500
            if sum(dat.rnveg_matrix2{i}{k}(:,h))>1200*0.75*200
                dat.rnveg_matrix2{i}{k}(:,h) = 1200;
            end
        end
        [~,dat.veg_edge.ind_max{i}{k}]      = max(diff(dat.rnveg_matrix{i}{k}')); % find marsh edge
        for g = 1:200
            if isempty(find(dat.rnveg_matrix2{i}{k}(g,:)>1199,1))==0
                dat.veg_edge.ind_max2{i}{k}(g)  = find(dat.rnveg_matrix2{i}{k}(g,:)>1189,1);
            else
                dat.veg_edge.ind_max2{i}{k}(g)=NaN;
            end
        end
        dat.rnveg_longshoremean{i}(1:500,k) = mean(dat.rnveg_matrix{1,i}{k});
        dat.veg_edge.mean_all{i}(k,1:200) = dat.veg_edge.ind_max{i}{k}*cellsize;
        dat.veg_edge.mean_all2{i}(k,1:200) = dat.veg_edge.ind_max2{i}{k}*cellsize;
        dat.veg_edge.mean{i}(k)    = (mean(dat.veg_edge.ind_max{i}{k})*cellsize);
        dat.veg_edge.mean2{i}(k)    = (mean(dat.veg_edge.ind_max2{i}{k})*cellsize);
        dat.veg_edge.std{i}(k)    = (std(dat.veg_edge.ind_max{i}{k})*cellsize);
        dat.veg_edge.min{i}(k)    = (min(dat.veg_edge.ind_max{i}{k})*cellsize);
        dat.veg_edge.min2{i}(k)    = (min(dat.veg_edge.ind_max2{i}{k})*cellsize);
        dat.veg_edge.max{i}(k)    = (max(dat.veg_edge.ind_max{i}{k})*cellsize);
        dat.veg_edge.max2{i}(k)    = (max(dat.veg_edge.ind_max2{i}{k})*cellsize);        
        
    end
    
    for a = 1:37
        for b = 1:200
                    dat.bl_height.mean_all2{i}(a,b) =...
                        mean(dat.bl_matrix{i}{1}...
                        (b,dat.veg_edge.mean_all2{i}(a,b)/5:end));
                    dat.edge_height.mean_all2{i}(a,b) =...
                        dat.bl_matrix{i}{1}...
                        (b,dat.veg_edge.mean_all2{i}(a,b)/5);
        end
    end

    dat.fin.veg_edge_mean(i) = 2500-mean(dat.veg_edge.mean_all2{i}(:));
    dat.fin.veg_edge_std(i) = std(dat.veg_edge.mean_all2{i}(:));
    dat.fin.veg_edge_min(i) = 2500-min(dat.veg_edge.min2{i}(:));
    dat.fin.veg_edge_max(i) = 2500-max(dat.veg_edge.max2{i}(:));
    
    dat.fin.bl_height_mean(i) = mean(dat.bl_height.mean_all2{i}(:));
    dat.fin.bl_height_std(i) = std(dat.bl_height.mean_all2{i}(:));
    dat.fin.bl_height_min(i) = min(dat.bl_height.mean_all2{i}(:));
    dat.fin.bl_height_max(i) = max(dat.bl_height.mean_all2{i}(:));

    dat.fin.edge_height_mean(i) = mean(dat.edge_height.mean_all2{i}(:));
    dat.fin.edge_height_std(i) = std(dat.edge_height.mean_all2{i}(:));
    dat.fin.edge_height_min(i) = min(dat.edge_height.mean_all2{i}(:));
    dat.fin.edge_height_max(i) = max(dat.edge_height.mean_all2{i}(:));

end

%% Interpolate areas
x_bar = [0.5:1:3.5];
x_interp = [0.5:0.1:3.5];
dat.fin.veg_edge_mean_interp = interp1(x_bar,dat.fin.veg_edge_mean,x_interp,'cubic');
dat.fin.veg_edge_min_interp = interp1(x_bar,dat.fin.veg_edge_min,x_interp,'cubic');
dat.fin.veg_edge_max_interp = interp1(x_bar,dat.fin.veg_edge_max,x_interp,'cubic');

dat.fin.bl_height_mean_interp = interp1(x_bar,dat.fin.bl_height_mean,x_interp,'cubic');
dat.fin.bl_height_min_interp = interp1(x_bar,dat.fin.bl_height_min,x_interp,'cubic');
dat.fin.bl_height_max_interp = interp1(x_bar,dat.fin.bl_height_max,x_interp,'cubic');

dat.fin.edge_height_mean_interp = interp1(x_bar,dat.fin.edge_height_mean,x_interp,'cubic');
dat.fin.edge_height_min_interp = interp1(x_bar,dat.fin.edge_height_min,x_interp,'cubic');
dat.fin.edge_height_max_interp = interp1(x_bar,dat.fin.edge_height_max,x_interp,'cubic');

dat.fin.safety_mean = dat.fin.veg_edge_mean.*dat.fin.bl_height_mean;
dat.fin.safety_min = dat.fin.veg_edge_max.*dat.fin.bl_height_min;
dat.fin.safety_max = dat.fin.veg_edge_min.*dat.fin.bl_height_max;

dat.fin.safety_mean_interp = dat.fin.veg_edge_mean_interp./100.*(dat.fin.edge_height_mean_interp+2); %dat.fin.bl_height_mean_interp.*
dat.fin.safety_min_interp = dat.fin.veg_edge_max_interp./100.*(dat.fin.edge_height_min_interp+2); %dat.fin.bl_height_min_interp.*
dat.fin.safety_max_interp = dat.fin.veg_edge_min_interp./100.*(dat.fin.edge_height_max_interp+2); %dat.fin.bl_height_max_interp.*

%% Plot Figure with mean and min / max
cmap = viridis(4);
F2 = figure
txt = [{'H_s=0.00m'},{'H_s=0.05m'},{'H_s=0.10m'},{'H_s=0.15m'}];

subplot(4,4,[1,5,9])
fill([x_interp fliplr(x_interp)],[dat.fin.veg_edge_min_interp,fliplr(dat.fin.veg_edge_max_interp)],...
    cmap(4,:),'edgecolor','none','facealpha','0.5');
hold on;
plot(x_interp,dat.fin.veg_edge_mean_interp,'color',cmap(3,:),'linewidth',2);

for i = 1:4
    plot([-0.5+i,-0.5+i],[(dat.fin.veg_edge_max(i)),(dat.fin.veg_edge_min(i))],'-','color',cmap(1,:),'linewidth',2);
    plot([-0.5+i],[dat.fin.veg_edge_mean(i)],'o','color',cmap(1,:),'markerfacecolor',cmap(1,:),'markersize',6);
    plot([-0.5+i],[dat.fin.veg_edge_min(i)],'s','color',cmap(1,:),'markerfacecolor',cmap(1,:));
    plot([-0.5+i],[dat.fin.veg_edge_max(i)],'s','color',cmap(1,:),'markerfacecolor',cmap(1,:));
end
ylabel('cross-shore width of salt marsh (m)');
xlabel('increasing H_s (m) \rightarrow');
set(gca,'xtick',[0.5,1.5,2.5,3.5,4.5],'xticklabel',{'0.00','0.05','0.10','0.15'},'xticklabelrotation',90)
text(0.1,2350,'a.')
grid on; xlim([0,4]); ylim([0,2500]);

subplot(4,4,[2,6,10])
fill([x_interp fliplr(x_interp)],[dat.fin.edge_height_min_interp,fliplr(dat.fin.edge_height_max_interp)],...
    cmap(4,:),'edgecolor','none','facealpha','0.5');
hold on;
plot(x_interp,dat.fin.edge_height_mean_interp,'color',cmap(3,:),'linewidth',2);

for i = 1:4
    plot([-0.5+i,-0.5+i],[(dat.fin.edge_height_max(i)),(dat.fin.edge_height_min(i))],'-','color',cmap(1,:),'linewidth',2);
    plot([-0.5+i],[dat.fin.edge_height_mean(i)],'o','color',cmap(1,:),'markerfacecolor',cmap(1,:),'markersize',6);
    plot([-0.5+i],[dat.fin.edge_height_min(i)],'s','color',cmap(1,:),'markerfacecolor',cmap(1,:));
    plot([-0.5+i],[dat.fin.edge_height_max(i)],'s','color',cmap(1,:),'markerfacecolor',cmap(1,:));
end
ylabel('elevation of salt marsh edge (m)');
xlabel('increasing H_s (m) \rightarrow');
set(gca,'xtick',[0.5,1.5,2.5,3.5,4.5],'xticklabel',{'0.00','0.05','0.10','0.15'},'xticklabelrotation',90,'ytick',[-2,-1,0,1,2,3])
text(0.1,2.7,'b.')
grid on; xlim([0,4]); ylim([-2,3]);

subplot(4,4,[3,7,11])
fill([x_interp fliplr(x_interp)],[dat.fin.bl_height_min_interp,fliplr(dat.fin.bl_height_max_interp)],...
    cmap(4,:),'edgecolor','none','facealpha','0.5');
hold on;
plot(x_interp,dat.fin.bl_height_mean_interp,'color',cmap(3,:),'linewidth',2);

for i = 1:4
    plot([-0.5+i,-0.5+i],[(dat.fin.bl_height_min(i)),(dat.fin.bl_height_max(i))],'-','color',cmap(2,:),'linewidth',2);
    plot([-0.5+i],[dat.fin.bl_height_mean(i)],'o','color',cmap(2,:),'markerfacecolor',cmap(2,:),'markersize',6);
    plot([-0.5+i],[dat.fin.bl_height_min(i)],'s','color',cmap(2,:),'markerfacecolor',cmap(2,:));
    plot([-0.5+i],[dat.fin.bl_height_max(i)],'s','color',cmap(2,:),'markerfacecolor',cmap(2,:));
end
ylabel('average height of salt marsh platform (m+msl)');
xlabel('increasing H_s (m) \rightarrow');
set(gca,'xtick',[0.5,1.5,2.5,3.5],'xticklabel',{'0.00','0.05','0.10','0.15'},'xticklabelrotation',90)
text(0.1,2350/2500*2.5+0.5,'c.')
grid on; xlim([0,4]); ylim([0.5,3]); 

subplot(4,4,[4,8,12])
fill([0,0,4,4,0],[4,40,40,4,4],[0.5,0.5,0.5],'edgecolor','none','facealpha',0.5);
hold on;
fill([x_interp fliplr(x_interp)],[dat.fin.safety_min_interp,fliplr(dat.fin.safety_max_interp)],...
    [cmap(4,:)],'edgecolor','none','facealpha',0.2);
plot(x_interp,dat.fin.safety_mean_interp,'color',cmap(3,:),'linewidth',2);

ylabel('potential wave attenuating capacity \rightarrow');
xlabel('increasing H_s \rightarrow');
set(gca,'xticklabel',[],'xtick',[],'yticklabel',[],'ytick',[]);
text(0.1,2350/2500*40,'d.')
grid on; xlim([0,4]); ylim([4,40]);

annotation('line',[0.71,0.71],[0.2,0.95],'linestyle','--','linewidth',2)

subplot(4,4,[13:16])
PL1 = fill([x_interp fliplr(x_interp)],[dat.fin.veg_edge_min_interp,fliplr(dat.fin.veg_edge_max_interp)],...
    cmap(4,:),'edgecolor','none','facealpha','0.5');
hold on;
PL2 = plot(x_interp,dat.fin.veg_edge_mean_interp,'color',cmap(3,:),'linewidth',2);
PL3 = plot([-0.5+i,-0.5+i],[(dat.fin.veg_edge_max(i)),(dat.fin.veg_edge_min(i))],'-','color','k','linewidth',2);
PL4 = plot([-0.5+i],[dat.fin.veg_edge_mean(i)],'o','color','k','markerfacecolor',cmap(1,:),'markersize',6);
PL5 = plot([-0.5+i],[dat.fin.veg_edge_min(i)],'s','color','k','markerfacecolor',cmap(1,:));
axis off; xlim([-10,-9]); ylim([-10,-9]);

LP = legend([PL3,PL4,PL5,PL2,PL1],{'total','mean','min/max','mean interp','min/max interp'},'orientation','horizontal')
LP.Position(2) = LP.Position(2)-0.1; 

set(findall(gcf,'-property','FontSize'),'FontSize',9)

print(F2,'Safety_Synthesis_Fig','-dpng','-r300')